@@ -1,7 +1,7 @@
 (*****************************************************************************
 
   Liquidsoap, a programmable audio stream generator.
-  Copyright 2003-2006 Savonet team
+  Copyright 2003-2007 Savonet team
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -26,4 +26,4 @@ let metadatas file =
   with
     | _ -> []
 
-let _ = Request.mresolvers#register "MP3" metadatas
+let () = Request.mresolvers#register "MP3" metadatas
