@@ -1,7 +1,7 @@
 (*****************************************************************************
 
   Liquidsoap, a programmable audio stream generator.
-  Copyright 2003-2006 Savonet team
+  Copyright 2003-2007 Savonet team
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@
 
 let fname = ref ""
 
-let _ =
+let () =
   Arg.parse [] (fun s -> fname := s) "";
   List.iter (fun (n, t) -> Printf.printf "%s: %s\n%!" n t)
     (Id3tag.get_tags !fname)
