@@ -1,7 +1,7 @@
 (*****************************************************************************
 
   Liquidsoap, a programmable audio stream generator.
-  Copyright 2003-2006 Savonet team
+  Copyright 2003-2007 Savonet team
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -26,27 +26,23 @@
 
 open Dtools
 
-let home =
-  try Sys.getenv "HOME" with Not_found -> "/nonexistent"
+let conf =
+  Conf.void ~p:(Configure.conf#plug "request") "requests configuration"
+let conf_max_rid =
+  Conf.int ~p:(conf#plug "max_id") ~d:Configure.requests_max_id
+    "maximum number of requests"
+
+let log = Log.make ["request"]
 
 (** File utilities. *)
 
 let remove_file_proto =
+  (* TODO Use PCRE *)
   let re = Str.regexp "^file://" in
     fun s ->
       Str.replace_first re "" s
 
-let home_unrelate s =
-  let s = remove_file_proto s in
-  if String.length s >= 2 then
-    match (s.[0] = '~'), (s.[1] = '/') with
-      | true, true ->  (* Something like ~/data/file *)
-	  Filename.concat home (String.sub s 2 (String.length s - 2))
-      | true, false -> (* Something like ~bob/data/file *)
-	  (Unix.getpwnam (String.sub s 1 (String.length s - 1))).Unix.pw_dir
-      | _ -> s
-  else
-    s
+let home_unrelate s = Utils.home_unrelate (remove_file_proto s)
 
 let parse_uri uri =
   try
@@ -147,7 +143,7 @@ let short_string_of_metadata m =
 type log = (Unix.tm * string) Queue.t
 
 let pretty_date date =
-  Printf.sprintf "%d/%d/%d %02d:%02d:%02d"
+  Printf.sprintf "%d/%02d/%02d %02d:%02d:%02d"
     (date.Unix.tm_year+1900)
     (date.Unix.tm_mon+1) date.Unix.tm_mday
     date.Unix.tm_hour date.Unix.tm_min date.Unix.tm_sec
@@ -268,7 +264,7 @@ let get_all_metadata t =
 
 (** Logging *)
 
-let log t i =
+let add_log t i =
   Queue.add ((Unix.localtime (Unix.time ())),i) t.log
 
 let get_log t = t.log
@@ -297,15 +293,15 @@ let rec pop_indicator t =
         Unix.unlink i.string
       with
         | e ->
-            Log.log ~label:"request" 2
-              (Log.f "Unlink failed: %S" (Printexc.to_string e))
+            log#f 2 "Unlink failed: %S" (Printexc.to_string e)
       end ;
     t.decoder <- None ;
     if repop then pop_indicator t
 
 let mresolvers_doc =
   "Methods to extract metadata from a file."
-let mresolvers = Plug.create ~doc:mresolvers_doc ~insensitive:true "mresolvers"
+let mresolvers =
+  Plug.create ~doc:mresolvers_doc ~insensitive:true "metadata formats"
 
 let local_check t =
   if t.audio then try
@@ -333,7 +329,7 @@ let local_check t =
 let push_indicators t l =
   if l <> [] then
     let hd = List.hd l in
-      log t (Printf.sprintf "Pushed [%S;...]." hd.string) ;
+      add_log t (Printf.sprintf "Pushed [%S;...]." hd.string) ;
       t.indicators <- l::t.indicators ;
       t.decoder <- None ;
       (* Performing a local check is quite fast and allows the request
@@ -399,18 +395,18 @@ let get_root_metadata t = update_metadata t ; get_root_metadata t
 
 let requests = Hashtbl.create Configure.requests_table_size
 (* Maximum number of alive requests *)
-let _ = Var.register "max_rid" Var.Int
-let max = Conf.ref_int ~default:Configure.requests_max_id "max_rid"
+
 let lock = Mutex.create ()
 
 exception Found of int
 
 let next =
+  let request_max = conf_max_rid#get in
   let current = ref (-1) in fun () ->
     assert (not (Mutex.try_lock lock)) ;
     try
-      for i = 1 to !max do
-        current := (!current+1) mod !max ;
+      for i = 1 to request_max do
+        current := (!current+1) mod request_max ;
         begin try
           let t = Hashtbl.find requests !current in
             if t.status = Destroyed then
@@ -471,7 +467,7 @@ let create ?(metadata=[]) ?(audio=true) ?(persistent=false) ?(indicators=[]) u =
   let rid = next () in
     if rid = -1 then
       ( Mutex.unlock lock ;
-	Log.log ~label:"request" 2 "No available RID!" ;
+	log#f 2 "No available RID!" ;
 	None )
     else
       let t = {
@@ -501,7 +497,7 @@ let create ?(metadata=[]) ?(audio=true) ?(persistent=false) ?(indicators=[]) u =
 let on_air t =
   t.on_air <- Some (Unix.time ()) ;
   t.status <- Playing ;
-  log t "Currently on air."
+  add_log t "Currently on air."
 
 let destroy ?force t =
   assert (t.status <> Destroyed) ;
@@ -514,7 +510,7 @@ let destroy ?force t =
     (* Remove the URIs, unlink temporary files *)
     while t.indicators <> [] do pop_indicator t done ;
     t.status <- Destroyed ;
-    log t "Request finished." ;
+    add_log t "Request finished." ;
   end
 
 let clean () =
@@ -567,17 +563,18 @@ let resolve t timeout =
     let proto,arg = parse_uri i.string in
       match protocols#get proto with
         | Some handler ->
-            log t (Printf.sprintf
+            add_log t (Printf.sprintf
                      "Resolving %S (timeout %.fs)..." i.string timeout) ;
-            let production = handler.resolve ~log:(log t) arg maxtime in
+            let production = handler.resolve ~log:(add_log t) arg maxtime in
               if production = [] then begin
-                Dtools.Log.log 4 ~label:"request"
-                  (Dtools.Log.f "Failed to resolve %S! See request's log (telnet command 'trace %d' for more information." i.string t.id) ;
+                log#f 4
+                  "Failed to resolve %S! For more info, see server command 'trace %d'."
+                  i.string t.id ;
                 ignore (pop_indicator t)
               end else
                 push_indicators t production
         | None ->
-            log t "Unknown protocol!" ;
+            add_log t "Unknown protocol!" ;
             pop_indicator t
   in
   let result =
@@ -587,17 +584,16 @@ let resolve t timeout =
 	  if timeleft > 0. then
             resolve_step ()
 	  else
-            ( log t "Global timeout." ; raise ExnTimeout )
+            ( add_log t "Global timeout." ; raise ExnTimeout )
       done ;
       Resolved
     with
       | ExnTimeout -> Timeout
-      | No_indicator -> log t "Every possibility failed!" ; Failed
+      | No_indicator -> add_log t "Every possibility failed!" ; Failed
   in
   let excess = (Unix.time ()) -. maxtime in
     if excess > 0. then
-      Dtools.Log.log ~label:"request"
-        2 (Printf.sprintf "Time limit exceeded by %f secs!" excess) ;
+      log#f 2 "Time limit exceeded by %f secs!" excess ;
     t.resolving <- None ;
     if result <> Resolved then t.status <- Idle else t.status <- Ready ;
     result
