@@ -1,7 +1,7 @@
 (*****************************************************************************
 
   Liquidsoap, a programmable audio stream generator.
-  Copyright 2003-2006 Savonet team
+  Copyright 2003-2007 Savonet team
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -20,8 +20,11 @@
 
  *****************************************************************************)
 
+val conf : Dtools.Conf.ut
+
 (** The core loop, reading from the scheduler and controlling output. *)
 val start : unit -> unit
+val running : unit -> bool
 
 (** Set [shutdown] to false to stop the loop *)
 val shutdown : bool ref
