@@ -1,7 +1,7 @@
 (*****************************************************************************
 
   Liquidsoap, a programmable audio stream generator.
-  Copyright 2003-2006 Savonet team
+  Copyright 2003-2007 Savonet team
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -29,5 +29,5 @@ type mode = Recv | Send
 
 (** [new_session addr port] *)
 val new_session : ?ttl:int -> mode -> string -> int -> t
-val recv : ?nosync:bool -> t -> Mixer.Buffer.t -> unit
-val send : ?nosync:bool -> t -> Mixer.Buffer.t -> unit
+val recv : ?nosync:bool -> t -> AFrame.t -> unit
+val send : ?nosync:bool -> t -> AFrame.t -> unit
